# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/workflows/Workflow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.nn.v07 import Results_pb2 as buffers_dot_protobuf_dot_nn_dot_v07_dot_Results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)buffers/protobuf/workflows/Workflow.proto\x12\x1a\x62uffers.protobuf.workflows\x1a%buffers/protobuf/nn/v07/Results.proto\"J\n\x0bPredictions\x12;\n\x0bpredictions\x18\x01 \x03(\x0b\x32&.buffers.protobuf.workflows.Prediction\"A\n\nPrediction\x12\x10\n\x08label_id\x18\x01 \x01(\r\x12\x12\n\nlabel_name\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\x02\"<\n\x04\x46ile\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x11\n\tmime_type\x18\x03 \x01(\t\"\xff\x01\n\x07\x43oncept\x12\x0f\n\x05image\x18\x01 \x01(\x0cH\x00\x12\x0e\n\x04text\x18\x02 \x01(\tH\x00\x12\x10\n\x06number\x18\x03 \x01(\x01H\x00\x12>\n\x0bpredictions\x18\x04 \x01(\x0b\x32\'.buffers.protobuf.workflows.PredictionsH\x00\x12\x34\n\x06region\x18\x05 \x01(\x0b\x32\".buffers.protobuf.workflows.RegionH\x00\x12\x11\n\x07\x62oolean\x18\x06 \x01(\x08H\x00\x12\x30\n\x04\x66ile\x18\x07 \x01(\x0b\x32 .buffers.protobuf.workflows.FileH\x00\x42\x06\n\x04type\"\xe9\x01\n\x06Region\x12\x31\n\x03roi\x18\x01 \x01(\x0b\x32$.buffers.protobuf.nn.v07.results.ROI\x12\x42\n\x08\x63oncepts\x18\x02 \x03(\x0b\x32\x30.buffers.protobuf.workflows.Region.ConceptsEntry\x12\x12\n\nentry_name\x18\x03 \x01(\t\x1aT\n\rConceptsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.buffers.protobuf.workflows.Concept:\x02\x38\x01\"{\n\x10WorkflowDataItem\x12\x32\n\x05\x65ntry\x18\x01 \x01(\x0b\x32#.buffers.protobuf.workflows.Concept\x12\x33\n\x07regions\x18\x02 \x03(\x0b\x32\".buffers.protobuf.workflows.Region\"\xc2\x02\n\rFlowContainer\x12R\n\rworkflow_data\x18\x01 \x03(\x0b\x32;.buffers.protobuf.workflows.FlowContainer.WorkflowDataEntry\x12I\n\x08metadata\x18\x02 \x03(\x0b\x32\x37.buffers.protobuf.workflows.FlowContainer.MetadataEntry\x1a\x61\n\x11WorkflowDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.buffers.protobuf.workflows.WorkflowDataItem:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"u\n\x07Outcome\x12\x35\n\x08\x63oncepts\x18\x01 \x03(\x0b\x32#.buffers.protobuf.workflows.Concept\x12\x33\n\x07regions\x18\x02 \x03(\x0b\x32\".buffers.protobuf.workflows.Regionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.workflows.Workflow_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGION_CONCEPTSENTRY._options = None
  _REGION_CONCEPTSENTRY._serialized_options = b'8\001'
  _FLOWCONTAINER_WORKFLOWDATAENTRY._options = None
  _FLOWCONTAINER_WORKFLOWDATAENTRY._serialized_options = b'8\001'
  _FLOWCONTAINER_METADATAENTRY._options = None
  _FLOWCONTAINER_METADATAENTRY._serialized_options = b'8\001'
  _PREDICTIONS._serialized_start=112
  _PREDICTIONS._serialized_end=186
  _PREDICTION._serialized_start=188
  _PREDICTION._serialized_end=253
  _FILE._serialized_start=255
  _FILE._serialized_end=315
  _CONCEPT._serialized_start=318
  _CONCEPT._serialized_end=573
  _REGION._serialized_start=576
  _REGION._serialized_end=809
  _REGION_CONCEPTSENTRY._serialized_start=725
  _REGION_CONCEPTSENTRY._serialized_end=809
  _WORKFLOWDATAITEM._serialized_start=811
  _WORKFLOWDATAITEM._serialized_end=934
  _FLOWCONTAINER._serialized_start=937
  _FLOWCONTAINER._serialized_end=1259
  _FLOWCONTAINER_WORKFLOWDATAENTRY._serialized_start=1113
  _FLOWCONTAINER_WORKFLOWDATAENTRY._serialized_end=1210
  _FLOWCONTAINER_METADATAENTRY._serialized_start=1212
  _FLOWCONTAINER_METADATAENTRY._serialized_end=1259
  _OUTCOME._serialized_start=1261
  _OUTCOME._serialized_end=1378
# @@protoc_insertion_point(module_scope)
