# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/v07/Results.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.common import Image_pb2 as buffers_dot_protobuf_dot_common_dot_Image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%buffers/protobuf/nn/v07/Results.proto\x12\x1f\x62uffers.protobuf.nn.v07.results\x1a#buffers/protobuf/common/Image.proto\"\x83\x01\n\tInference\x12\x42\n\x07tensors\x18\x01 \x03(\x0b\x32\x31.buffers.protobuf.nn.v07.results.Inference.Tensor\x1a\x32\n\x06Tensor\x12\x0c\n\x04\x64ims\x18\x01 \x03(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x02\x12\x0c\n\x04name\x18\x03 \x01(\t\"g\n\x04Mask\x12+\n\x04\x62\x62ox\x18\x01 \x01(\x0b\x32\x1d.buffers.protobuf.common.BBox\x12\x32\n\x08polygons\x18\x02 \x03(\x0b\x32 .buffers.protobuf.common.Polygon\"\x86\x01\n\x03ROI\x12\x11\n\tregion_id\x18\x01 \x01(\r\x12-\n\x04\x62\x62ox\x18\x03 \x01(\x0b\x32\x1d.buffers.protobuf.common.BBoxH\x00\x12\x35\n\x04mask\x18\x04 \x01(\x0b\x32%.buffers.protobuf.nn.v07.results.MaskH\x00\x42\x06\n\x04type\"\xb2\x02\n\x0cLabelsOutput\x12K\n\tpredicted\x18\x01 \x03(\x0b\x32\x38.buffers.protobuf.nn.v07.results.LabelsOutput.Prediction\x12K\n\tdiscarded\x18\x02 \x03(\x0b\x32\x38.buffers.protobuf.nn.v07.results.LabelsOutput.Prediction\x1a\x87\x01\n\nPrediction\x12\x10\n\x08label_id\x18\x01 \x01(\r\x12\x12\n\nlabel_name\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\x02\x12\x11\n\tthreshold\x18\x04 \x01(\x02\x12\x31\n\x03roi\x18\x05 \x01(\x0b\x32$.buffers.protobuf.nn.v07.results.ROI\")\n\x0cScalarOutput\x12\x11\n\x07integer\x18\x01 \x01(\x04H\x00\x42\x06\n\x04type\"N\n\nTextOutput\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nmean_score\x18\x02 \x01(\x02\x12\x0e\n\x06tokens\x18\x03 \x03(\t\x12\x0e\n\x06scores\x18\x04 \x03(\x02\"\xd7\x01\n\x0eRecognitionMix\x12?\n\x06labels\x18\x01 \x01(\x0b\x32-.buffers.protobuf.nn.v07.results.LabelsOutputH\x00\x12?\n\x06scalar\x18\x02 \x01(\x0b\x32-.buffers.protobuf.nn.v07.results.ScalarOutputH\x00\x12;\n\x04text\x18\x03 \x01(\x0b\x32+.buffers.protobuf.nn.v07.results.TextOutputH\x00\x42\x06\n\x04type\"O\n\x0bRecognition\x12@\n\x07outputs\x18\x01 \x03(\x0b\x32/.buffers.protobuf.nn.v07.results.RecognitionMixb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.v07.Results_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INFERENCE._serialized_start=112
  _INFERENCE._serialized_end=243
  _INFERENCE_TENSOR._serialized_start=193
  _INFERENCE_TENSOR._serialized_end=243
  _MASK._serialized_start=245
  _MASK._serialized_end=348
  _ROI._serialized_start=351
  _ROI._serialized_end=485
  _LABELSOUTPUT._serialized_start=488
  _LABELSOUTPUT._serialized_end=794
  _LABELSOUTPUT_PREDICTION._serialized_start=659
  _LABELSOUTPUT_PREDICTION._serialized_end=794
  _SCALAROUTPUT._serialized_start=796
  _SCALAROUTPUT._serialized_end=837
  _TEXTOUTPUT._serialized_start=839
  _TEXTOUTPUT._serialized_end=917
  _RECOGNITIONMIX._serialized_start=920
  _RECOGNITIONMIX._serialized_end=1135
  _RECOGNITION._serialized_start=1137
  _RECOGNITION._serialized_end=1216
# @@protoc_insertion_point(module_scope)
