# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/v07/Workflows.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'buffers/protobuf/nn/v07/Workflows.proto\x12!buffers.protobuf.nn.v07.workflows\"}\n\x08\x43onsumer\x12@\n\x04\x61mqp\x18\x01 \x01(\x0b\x32\x30.buffers.protobuf.nn.v07.workflows.Consumer.AMQPH\x00\x1a\'\n\x04\x41MQP\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\r\n\x05queue\x18\x02 \x01(\tB\x06\n\x04type\"\x82\x02\n\x0eTransformation\x12L\n\x07network\x18\x01 \x01(\x0b\x32\x39.buffers.protobuf.nn.v07.workflows.Transformation.NetworkH\x00\x12T\n\x0brecognition\x18\x02 \x01(\x0b\x32=.buffers.protobuf.nn.v07.workflows.Transformation.RecognitionH\x00\x1a\x1d\n\x07Network\x12\x12\n\nnetwork_id\x18\x01 \x01(\x05\x1a%\n\x0bRecognition\x12\x16\n\x0erecognition_id\x18\x01 \x01(\x05\x42\x06\n\x04type\"\xa3\x01\n\x08Workflow\x12\x0c\n\x04name\x18\x01 \x01(\t\x12=\n\x08\x63onsumer\x18\x02 \x01(\x0b\x32+.buffers.protobuf.nn.v07.workflows.Consumer\x12J\n\x0ftransformations\x18\x03 \x03(\x0b\x32\x31.buffers.protobuf.nn.v07.workflows.Transformation\"K\n\tWorkflows\x12>\n\tworkflows\x18\x01 \x03(\x0b\x32+.buffers.protobuf.nn.v07.workflows.Workflowb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.v07.Workflows_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONSUMER._serialized_start=78
  _CONSUMER._serialized_end=203
  _CONSUMER_AMQP._serialized_start=156
  _CONSUMER_AMQP._serialized_end=195
  _TRANSFORMATION._serialized_start=206
  _TRANSFORMATION._serialized_end=464
  _TRANSFORMATION_NETWORK._serialized_start=388
  _TRANSFORMATION_NETWORK._serialized_end=417
  _TRANSFORMATION_RECOGNITION._serialized_start=419
  _TRANSFORMATION_RECOGNITION._serialized_end=456
  _WORKFLOW._serialized_start=467
  _WORKFLOW._serialized_end=630
  _WORKFLOWS._serialized_start=632
  _WORKFLOWS._serialized_end=707
# @@protoc_insertion_point(module_scope)
