# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Command.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.nn.v07 import Commands_pb2 as buffers_dot_protobuf_dot_nn_dot_v07_dot_Commands__pb2
from deepomatic.rpc.buffers.protobuf.nn.v07 import Inputs_pb2 as buffers_dot_protobuf_dot_nn_dot_v07_dot_Inputs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!buffers/protobuf/nn/Command.proto\x12\x13\x62uffers.protobuf.nn\x1a&buffers/protobuf/nn/v07/Commands.proto\x1a$buffers/protobuf/nn/v07/Inputs.proto\"\xe8\x01\n\nCommandMix\x12\x44\n\rv07_inference\x18\x04 \x01(\x0b\x32+.buffers.protobuf.nn.v07.commands.InferenceH\x00\x12H\n\x0fv07_recognition\x18\x05 \x01(\x0b\x32-.buffers.protobuf.nn.v07.commands.RecognitionH\x00\x12\x42\n\x0cv07_workflow\x18\x06 \x01(\x0b\x32*.buffers.protobuf.nn.v07.commands.WorkflowH\x00\x42\x06\n\x04type\"P\n\x08InputMix\x12<\n\nv07_inputs\x18\x02 \x01(\x0b\x32&.buffers.protobuf.nn.v07.inputs.InputsH\x00\x42\x06\n\x04type\"\x12\n\x04Task\x12\n\n\x02id\x18\x01 \x01(\x05\"}\n\x0b\x43ommandInfo\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_pk\x18\x02 \x01(\x05\x12\x10\n\x08track_id\x18\x03 \x01(\t\x12\x11\n\tdate_plan\x18\x04 \x01(\t\x12\x15\n\rcurrent_queue\x18\x05 \x01(\r\x12\x12\n\nforward_to\x18\x06 \x03(\t\"\xcf\x01\n\x07\x43ommand\x12\'\n\x04task\x18\x01 \x01(\x0b\x32\x19.buffers.protobuf.nn.Task\x12\x33\n\tbase_info\x18\x02 \x01(\x0b\x32 .buffers.protobuf.nn.CommandInfo\x12\x34\n\x0b\x63ommand_mix\x18\x05 \x01(\x0b\x32\x1f.buffers.protobuf.nn.CommandMix\x12\x30\n\tinput_mix\x18\x06 \x01(\x0b\x32\x1d.buffers.protobuf.nn.InputMixb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Command_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMANDMIX._serialized_start=137
  _COMMANDMIX._serialized_end=369
  _INPUTMIX._serialized_start=371
  _INPUTMIX._serialized_end=451
  _TASK._serialized_start=453
  _TASK._serialized_end=471
  _COMMANDINFO._serialized_start=473
  _COMMANDINFO._serialized_end=598
  _COMMAND._serialized_start=601
  _COMMAND._serialized_end=808
# @@protoc_insertion_point(module_scope)
