# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/workflows/WorkOrder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*buffers/protobuf/workflows/WorkOrder.proto\x12\x1a\x62uffers.protobuf.workflows\"\xbb\x02\n\rWorkOrderData\x12I\n\x08metadata\x18\x01 \x03(\x0b\x32\x37.buffers.protobuf.workflows.WorkOrderData.MetadataEntry\x12\x45\n\x06states\x18\x02 \x03(\x0b\x32\x35.buffers.protobuf.workflows.WorkOrderData.StatesEntry\x12\r\n\x05types\x18\x03 \x03(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aX\n\x0bStatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).buffers.protobuf.workflows.WorkItemState:\x02\x38\x01\"\xa5\x01\n\rWorkItemState\x12P\n\x0cstate_values\x18\x01 \x03(\x0b\x32:.buffers.protobuf.workflows.WorkItemState.StateValuesEntry\x12\x0e\n\x06memory\x18\x02 \x01(\t\x1a\x32\n\x10StateValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.workflows.WorkOrder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKORDERDATA_METADATAENTRY._options = None
  _WORKORDERDATA_METADATAENTRY._serialized_options = b'8\001'
  _WORKORDERDATA_STATESENTRY._options = None
  _WORKORDERDATA_STATESENTRY._serialized_options = b'8\001'
  _WORKITEMSTATE_STATEVALUESENTRY._options = None
  _WORKITEMSTATE_STATEVALUESENTRY._serialized_options = b'8\001'
  _WORKORDERDATA._serialized_start=75
  _WORKORDERDATA._serialized_end=390
  _WORKORDERDATA_METADATAENTRY._serialized_start=253
  _WORKORDERDATA_METADATAENTRY._serialized_end=300
  _WORKORDERDATA_STATESENTRY._serialized_start=302
  _WORKORDERDATA_STATESENTRY._serialized_end=390
  _WORKITEMSTATE._serialized_start=393
  _WORKITEMSTATE._serialized_end=558
  _WORKITEMSTATE_STATEVALUESENTRY._serialized_start=508
  _WORKITEMSTATE_STATEVALUESENTRY._serialized_end=558
# @@protoc_insertion_point(module_scope)
