# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Postprocessing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(buffers/protobuf/nn/Postprocessing.proto\x12\"buffers.protobuf.nn.postprocessing\"#\n\x10RawTensorsOutput\x12\x0f\n\x07tensors\x18\x01 \x03(\t\"=\n\x0eStandardOutput\x12\x14\n\x0c\x62oxes_tensor\x18\x01 \x01(\t\x12\x15\n\rscores_tensor\x18\x02 \x01(\t\"w\n\x1aInstanceSegmentationOutput\x12\x14\n\x0c\x62oxes_tensor\x18\x01 \x01(\t\x12\x15\n\rscores_tensor\x18\x02 \x01(\t\x12\x16\n\x0e\x63lasses_tensor\x18\x03 \x01(\t\x12\x14\n\x0cmasks_tensor\x18\x04 \x01(\t\"W\n\x0e\x41nchoredOutput\x12\x16\n\x0e\x61nchors_tensor\x18\x01 \x01(\t\x12\x16\n\x0eoffsets_tensor\x18\x02 \x01(\t\x12\x15\n\rscores_tensor\x18\x03 \x01(\t\"S\n\x0c\x44irectOutput\x12\x14\n\x0c\x62oxes_tensor\x18\x01 \x01(\t\x12\x15\n\rscores_tensor\x18\x02 \x01(\t\x12\x16\n\x0e\x63lasses_tensor\x18\x03 \x01(\t\"4\n\nYoloOutput\x12\x15\n\routput_tensor\x18\x01 \x01(\t\x12\x0f\n\x07\x61nchors\x18\x02 \x03(\x02\"7\n\x0cYoloV3Output\x12\x16\n\x0eoutput_tensors\x18\x01 \x03(\t\x12\x0f\n\x07\x61nchors\x18\x02 \x03(\x02\"\xe5\x04\n\x0ePostProcessing\x12M\n\x0f\x61nchored_output\x18\x01 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.AnchoredOutputH\x00\x12I\n\rdirect_output\x18\x02 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.DirectOutputH\x00\x12\x45\n\x0byolo_output\x18\x03 \x01(\x0b\x32..buffers.protobuf.nn.postprocessing.YoloOutputH\x00\x12I\n\ryolov3_output\x18\x04 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.YoloV3OutputH\x00\x12N\n\x0etensors_output\x18\x05 \x01(\x0b\x32\x34.buffers.protobuf.nn.postprocessing.RawTensorsOutputH\x00\x12M\n\x0fstandard_output\x18\x06 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.StandardOutputH\x00\x12\x66\n\x1cinstance_segmentation_output\x18\x07 \x01(\x0b\x32>.buffers.protobuf.nn.postprocessing.InstanceSegmentationOutputH\x00\x12\x18\n\x10\x65xpand_batch_dim\x18\x0f \x01(\x08\x42\x06\n\x04type\"^\n\x0fPostProcessings\x12K\n\x0fpostprocessings\x18\x01 \x03(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.PostProcessing\"\xfc\x01\n\x0cLabelsOutput\x12\x46\n\x06labels\x18\x01 \x03(\x0b\x32\x36.buffers.protobuf.nn.postprocessing.LabelsOutput.Label\x12\x11\n\texclusive\x18\x02 \x01(\x08\x12\x45\n\x03roi\x18\x03 \x01(\x0e\x32\x38.buffers.protobuf.nn.postprocessing.LabelsOutput.ROIType\x1a!\n\x05Label\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"\'\n\x07ROIType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x42\x42OX\x10\x01\x12\x08\n\x04MASK\x10\x02\" \n\nTextOutput\x12\x12\n\ncharacters\x18\x01 \x03(\t\"\xeb\x01\n\x07Outputs\x12\x46\n\x07outputs\x18\x01 \x03(\x0b\x32\x35.buffers.protobuf.nn.postprocessing.Outputs.OutputMix\x1a\x97\x01\n\tOutputMix\x12\x42\n\x06labels\x18\x01 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.LabelsOutputH\x00\x12>\n\x04text\x18\x02 \x01(\x0b\x32..buffers.protobuf.nn.postprocessing.TextOutputH\x00\x42\x06\n\x04type\";\n\x0e\x43lassification\x12\x15\n\routput_tensor\x18\x01 \x01(\t\x12\x12\n\nthresholds\x18\x02 \x03(\x01\"\xcd\x04\n\tDetection\x12K\n\noutput_mix\x18\x01 \x01(\x0b\x32\x37.buffers.protobuf.nn.postprocessing.Detection.OutputMix\x12\x12\n\nthresholds\x18\x02 \x03(\x01\x12\x15\n\rnms_threshold\x18\x03 \x01(\x01\x12\x19\n\x11\x64iscard_threshold\x18\x04 \x01(\x01\x12\x1c\n\x14normalize_wrt_tensor\x18\x05 \x01(\t\x1a\x8e\x03\n\tOutputMix\x12M\n\x0f\x61nchored_output\x18\x01 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.AnchoredOutputH\x00\x12I\n\rdirect_output\x18\x02 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.DirectOutputH\x00\x12\x45\n\x0byolo_output\x18\x03 \x01(\x0b\x32..buffers.protobuf.nn.postprocessing.YoloOutputH\x00\x12I\n\ryolov3_output\x18\x04 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.YoloV3OutputH\x00\x12M\n\x0fstandard_output\x18\x05 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.StandardOutputH\x00\x42\x06\n\x04type\"\x05\n\x03OCR\"\x8a\x02\n\x0cSegmentation\x12N\n\noutput_mix\x18\x01 \x01(\x0b\x32:.buffers.protobuf.nn.postprocessing.Segmentation.OutputMix\x12\x12\n\nthresholds\x18\x02 \x03(\x01\x12\x19\n\x11\x64iscard_threshold\x18\x03 \x01(\x01\x1a{\n\tOutputMix\x12\x66\n\x1cinstance_segmentation_output\x18\x01 \x01(\x0b\x32>.buffers.protobuf.nn.postprocessing.InstanceSegmentationOutputH\x00\x42\x06\n\x04type\"\xcb\x03\n\x19PostprocessingsDeprecated\x12r\n\x0fpostprocessings\x18\x01 \x03(\x0b\x32Y.buffers.protobuf.nn.postprocessing.PostprocessingsDeprecated.PostprocessingMixDeprecated\x1a\xb9\x02\n\x1bPostprocessingMixDeprecated\x12L\n\x0e\x63lassification\x18\x01 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.ClassificationH\x00\x12\x42\n\tdetection\x18\x02 \x01(\x0b\x32-.buffers.protobuf.nn.postprocessing.DetectionH\x00\x12\x36\n\x03ocr\x18\x03 \x01(\x0b\x32\'.buffers.protobuf.nn.postprocessing.OCRH\x00\x12H\n\x0csegmentation\x18\x04 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.SegmentationH\x00\x42\x06\n\x04typeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Postprocessing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RAWTENSORSOUTPUT._serialized_start=80
  _RAWTENSORSOUTPUT._serialized_end=115
  _STANDARDOUTPUT._serialized_start=117
  _STANDARDOUTPUT._serialized_end=178
  _INSTANCESEGMENTATIONOUTPUT._serialized_start=180
  _INSTANCESEGMENTATIONOUTPUT._serialized_end=299
  _ANCHOREDOUTPUT._serialized_start=301
  _ANCHOREDOUTPUT._serialized_end=388
  _DIRECTOUTPUT._serialized_start=390
  _DIRECTOUTPUT._serialized_end=473
  _YOLOOUTPUT._serialized_start=475
  _YOLOOUTPUT._serialized_end=527
  _YOLOV3OUTPUT._serialized_start=529
  _YOLOV3OUTPUT._serialized_end=584
  _POSTPROCESSING._serialized_start=587
  _POSTPROCESSING._serialized_end=1200
  _POSTPROCESSINGS._serialized_start=1202
  _POSTPROCESSINGS._serialized_end=1296
  _LABELSOUTPUT._serialized_start=1299
  _LABELSOUTPUT._serialized_end=1551
  _LABELSOUTPUT_LABEL._serialized_start=1477
  _LABELSOUTPUT_LABEL._serialized_end=1510
  _LABELSOUTPUT_ROITYPE._serialized_start=1512
  _LABELSOUTPUT_ROITYPE._serialized_end=1551
  _TEXTOUTPUT._serialized_start=1553
  _TEXTOUTPUT._serialized_end=1585
  _OUTPUTS._serialized_start=1588
  _OUTPUTS._serialized_end=1823
  _OUTPUTS_OUTPUTMIX._serialized_start=1672
  _OUTPUTS_OUTPUTMIX._serialized_end=1823
  _CLASSIFICATION._serialized_start=1825
  _CLASSIFICATION._serialized_end=1884
  _DETECTION._serialized_start=1887
  _DETECTION._serialized_end=2476
  _DETECTION_OUTPUTMIX._serialized_start=2078
  _DETECTION_OUTPUTMIX._serialized_end=2476
  _OCR._serialized_start=2478
  _OCR._serialized_end=2483
  _SEGMENTATION._serialized_start=2486
  _SEGMENTATION._serialized_end=2752
  _SEGMENTATION_OUTPUTMIX._serialized_start=2629
  _SEGMENTATION_OUTPUTMIX._serialized_end=2752
  _POSTPROCESSINGSDEPRECATED._serialized_start=2755
  _POSTPROCESSINGSDEPRECATED._serialized_end=3214
  _POSTPROCESSINGSDEPRECATED_POSTPROCESSINGMIXDEPRECATED._serialized_start=2901
  _POSTPROCESSINGSDEPRECATED_POSTPROCESSINGMIXDEPRECATED._serialized_end=3214
# @@protoc_insertion_point(module_scope)
