# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/cli/Message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.nn import Command_pb2 as buffers_dot_protobuf_dot_nn_dot_Command__pb2
from deepomatic.rpc.buffers.protobuf.nn import Result_pb2 as buffers_dot_protobuf_dot_nn_dot_Result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"buffers/protobuf/cli/Message.proto\x12\x19\x62uffers.protobuf.deepocli\x1a!buffers/protobuf/nn/Command.proto\x1a buffers/protobuf/nn/Result.proto\"q\n\x07\x43ommand\x12\x34\n\x0b\x63ommand_mix\x18\x01 \x01(\x0b\x32\x1f.buffers.protobuf.nn.CommandMix\x12\x30\n\tinput_mix\x18\x02 \x01(\x0b\x32\x1d.buffers.protobuf.nn.InputMix\"k\n\x07Message\x12\x33\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\".buffers.protobuf.deepocli.Command\x12+\n\x06result\x18\x02 \x01(\x0b\x32\x1b.buffers.protobuf.nn.Resultb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.cli.Message_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMAND._serialized_start=134
  _COMMAND._serialized_end=247
  _MESSAGE._serialized_start=249
  _MESSAGE._serialized_end=356
# @@protoc_insertion_point(module_scope)
