# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Result.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.common import Error_pb2 as buffers_dot_protobuf_dot_common_dot_Error__pb2
from deepomatic.rpc.buffers.protobuf.nn.v07 import Results_pb2 as buffers_dot_protobuf_dot_nn_dot_v07_dot_Results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n buffers/protobuf/nn/Result.proto\x12\x13\x62uffers.protobuf.nn\x1a#buffers/protobuf/common/Error.proto\x1a%buffers/protobuf/nn/v07/Results.proto\"\xcf\x01\n\x06Result\x12/\n\x05\x65rror\x18\x06 \x01(\x0b\x32\x1e.buffers.protobuf.common.ErrorH\x00\x12\x43\n\rv07_inference\x18\x04 \x01(\x0b\x32*.buffers.protobuf.nn.v07.results.InferenceH\x00\x12G\n\x0fv07_recognition\x18\x05 \x01(\x0b\x32,.buffers.protobuf.nn.v07.results.RecognitionH\x00\x42\x06\n\x04typeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Result_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESULT._serialized_start=134
  _RESULT._serialized_end=341
# @@protoc_insertion_point(module_scope)
