# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/frameworks/Caffe.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*buffers/protobuf/nn/frameworks/Caffe.proto\x12$buffers.protobuf.nn.frameworks.caffe\"\x1c\n\tBlobShape\x12\x0f\n\x03\x64im\x18\x01 \x03(\x03\x42\x02\x10\x01\"\xeb\x01\n\tBlobProto\x12>\n\x05shape\x18\x07 \x01(\x0b\x32/.buffers.protobuf.nn.frameworks.caffe.BlobShape\x12\x10\n\x04\x64\x61ta\x18\x05 \x03(\x02\x42\x02\x10\x01\x12\x10\n\x04\x64iff\x18\x06 \x03(\x02\x42\x02\x10\x01\x12\x17\n\x0b\x64ouble_data\x18\x08 \x03(\x01\x42\x02\x10\x01\x12\x17\n\x0b\x64ouble_diff\x18\t \x03(\x01\x42\x02\x10\x01\x12\x0e\n\x03num\x18\x01 \x01(\x05:\x01\x30\x12\x13\n\x08\x63hannels\x18\x02 \x01(\x05:\x01\x30\x12\x11\n\x06height\x18\x03 \x01(\x05:\x01\x30\x12\x10\n\x05width\x18\x04 \x01(\x05:\x01\x30')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.frameworks.Caffe_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BLOBSHAPE.fields_by_name['dim']._options = None
  _BLOBSHAPE.fields_by_name['dim']._serialized_options = b'\020\001'
  _BLOBPROTO.fields_by_name['data']._options = None
  _BLOBPROTO.fields_by_name['data']._serialized_options = b'\020\001'
  _BLOBPROTO.fields_by_name['diff']._options = None
  _BLOBPROTO.fields_by_name['diff']._serialized_options = b'\020\001'
  _BLOBPROTO.fields_by_name['double_data']._options = None
  _BLOBPROTO.fields_by_name['double_data']._serialized_options = b'\020\001'
  _BLOBPROTO.fields_by_name['double_diff']._options = None
  _BLOBPROTO.fields_by_name['double_diff']._serialized_options = b'\020\001'
  _BLOBSHAPE._serialized_start=84
  _BLOBSHAPE._serialized_end=112
  _BLOBPROTO._serialized_start=115
  _BLOBPROTO._serialized_end=350
# @@protoc_insertion_point(module_scope)
