# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/v07/Commands.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&buffers/protobuf/nn/v07/Commands.proto\x12 buffers.protobuf.nn.v07.commands\"\x0b\n\tInference\"R\n\x0bRecognition\x12\x12\n\nversion_id\x18\x01 \x01(\x05\x12\x16\n\x0eshow_discarded\x18\x08 \x01(\x08\x12\x17\n\x0fmax_predictions\x18\t \x01(\x05\"\n\n\x08Workflowb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.v07.Commands_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INFERENCE._serialized_start=76
  _INFERENCE._serialized_end=87
  _RECOGNITION._serialized_start=89
  _RECOGNITION._serialized_end=171
  _WORKFLOW._serialized_start=173
  _WORKFLOW._serialized_end=183
# @@protoc_insertion_point(module_scope)
