# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/v07/Inputs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.common import Image_pb2 as buffers_dot_protobuf_dot_common_dot_Image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$buffers/protobuf/nn/v07/Inputs.proto\x12\x1e\x62uffers.protobuf.nn.v07.inputs\x1a#buffers/protobuf/common/Image.proto\"\x9b\x01\n\nImageInput\x12\x0e\n\x06source\x18\x01 \x01(\x0c\x12+\n\x04\x62\x62ox\x18\x02 \x01(\x0b\x32\x1d.buffers.protobuf.common.BBox\x12/\n\x07polygon\x18\x03 \x03(\x0b\x32\x1e.buffers.protobuf.common.Point\x12\x1f\n\x17\x63rop_uniform_background\x18\x04 \x01(\x08\"\x9a\x01\n\x06Inputs\x12?\n\x06inputs\x18\x01 \x03(\x0b\x32/.buffers.protobuf.nn.v07.inputs.Inputs.InputMix\x1aO\n\x08InputMix\x12;\n\x05image\x18\x01 \x01(\x0b\x32*.buffers.protobuf.nn.v07.inputs.ImageInputH\x00\x42\x06\n\x04typeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.v07.Inputs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMAGEINPUT._serialized_start=110
  _IMAGEINPUT._serialized_end=265
  _INPUTS._serialized_start=268
  _INPUTS._serialized_end=422
  _INPUTS_INPUTMIX._serialized_start=343
  _INPUTS_INPUTMIX._serialized_end=422
# @@protoc_insertion_point(module_scope)
