# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Preprocessing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'buffers/protobuf/nn/Preprocessing.proto\x12!buffers.protobuf.nn.preprocessing\")\n\nMeanTensor\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x02\"\xb4\x01\n\x15\x43onstantPreprocessing\x12\r\n\x05shape\x18\x01 \x03(\x05\x12L\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32>.buffers.protobuf.nn.preprocessing.ConstantPreprocessing.Entry\x1a>\n\x05\x45ntry\x12\x15\n\x0b\x66loat_entry\x18\x01 \x01(\x02H\x00\x12\x16\n\x0cstring_entry\x18\x02 \x01(\tH\x00\x42\x06\n\x04type\"\xff\x04\n\x12ImagePreprocessing\x12\x11\n\tmean_file\x18\x01 \x01(\t\x12[\n\x0e\x63olor_channels\x18\x02 \x01(\x0e\x32\x43.buffers.protobuf.nn.preprocessing.ImagePreprocessing.ColorChannels\x12]\n\x0f\x64imension_order\x18\x03 \x01(\x0e\x32\x44.buffers.protobuf.nn.preprocessing.ImagePreprocessing.DimensionOrder\x12U\n\x0bresize_type\x18\x04 \x01(\x0e\x32@.buffers.protobuf.nn.preprocessing.ImagePreprocessing.ResizeType\x12\x13\n\x0btarget_size\x18\x05 \x01(\t\x12\x15\n\rpixel_scaling\x18\x06 \x01(\x02\x12Q\n\tdata_type\x18\x07 \x01(\x0e\x32>.buffers.protobuf.nn.preprocessing.ImagePreprocessing.DataType\"9\n\nResizeType\x12\x0b\n\x07NETWORK\x10\x00\x12\x08\n\x04\x46ILL\x10\x02\x12\x08\n\x04\x43ROP\x10\x03\x12\n\n\x06SQUASH\x10\x04\"+\n\rColorChannels\x12\x07\n\x03\x42GR\x10\x00\x12\x07\n\x03RGB\x10\x01\x12\x08\n\x04GRAY\x10\x02\"8\n\x0e\x44imensionOrder\x12\x08\n\x04NCHW\x10\x00\x12\x08\n\x04NCWH\x10\x01\x12\x08\n\x04NHWC\x10\x02\x12\x08\n\x04NWHC\x10\x03\"\"\n\x08\x44\x61taType\x12\x0b\n\x07\x46LOAT32\x10\x00\x12\t\n\x05UINT8\x10\x01\"\xb0\x01\n\x10PreprocessingMix\x12L\n\x08\x63onstant\x18\x01 \x01(\x0b\x32\x38.buffers.protobuf.nn.preprocessing.ConstantPreprocessingH\x00\x12\x46\n\x05image\x18\x02 \x01(\x0b\x32\x35.buffers.protobuf.nn.preprocessing.ImagePreprocessingH\x00\x42\x06\n\x04type\"t\n\rPreprocessing\x12\x13\n\x0btensor_name\x18\x01 \x01(\t\x12N\n\x11preprocessing_mix\x18\x02 \x01(\x0b\x32\x33.buffers.protobuf.nn.preprocessing.PreprocessingMix\"j\n\x0ePreprocessings\x12@\n\x06inputs\x18\x01 \x03(\x0b\x32\x30.buffers.protobuf.nn.preprocessing.Preprocessing\x12\x16\n\x0e\x62\x61tched_output\x18\x02 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Preprocessing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MEANTENSOR._serialized_start=78
  _MEANTENSOR._serialized_end=119
  _CONSTANTPREPROCESSING._serialized_start=122
  _CONSTANTPREPROCESSING._serialized_end=302
  _CONSTANTPREPROCESSING_ENTRY._serialized_start=240
  _CONSTANTPREPROCESSING_ENTRY._serialized_end=302
  _IMAGEPREPROCESSING._serialized_start=305
  _IMAGEPREPROCESSING._serialized_end=944
  _IMAGEPREPROCESSING_RESIZETYPE._serialized_start=748
  _IMAGEPREPROCESSING_RESIZETYPE._serialized_end=805
  _IMAGEPREPROCESSING_COLORCHANNELS._serialized_start=807
  _IMAGEPREPROCESSING_COLORCHANNELS._serialized_end=850
  _IMAGEPREPROCESSING_DIMENSIONORDER._serialized_start=852
  _IMAGEPREPROCESSING_DIMENSIONORDER._serialized_end=908
  _IMAGEPREPROCESSING_DATATYPE._serialized_start=910
  _IMAGEPREPROCESSING_DATATYPE._serialized_end=944
  _PREPROCESSINGMIX._serialized_start=947
  _PREPROCESSINGMIX._serialized_end=1123
  _PREPROCESSING._serialized_start=1125
  _PREPROCESSING._serialized_end=1241
  _PREPROCESSINGS._serialized_start=1243
  _PREPROCESSINGS._serialized_end=1349
# @@protoc_insertion_point(module_scope)
