# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.nn import Command_pb2 as buffers_dot_protobuf_dot_nn_dot_Command__pb2
from deepomatic.rpc.buffers.protobuf.nn import Result_pb2 as buffers_dot_protobuf_dot_nn_dot_Result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!buffers/protobuf/nn/Message.proto\x12\x13\x62uffers.protobuf.nn\x1a!buffers/protobuf/nn/Command.proto\x1a buffers/protobuf/nn/Result.proto\"q\n\x07Message\x12/\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\x1c.buffers.protobuf.nn.CommandH\x00\x12-\n\x06result\x18\x02 \x01(\x0b\x32\x1b.buffers.protobuf.nn.ResultH\x00\x42\x06\n\x04typeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Message_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGE._serialized_start=127
  _MESSAGE._serialized_end=240
# @@protoc_insertion_point(module_scope)
