# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/workflows/WorkflowExecution.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.workflows import Workflow_pb2 as buffers_dot_protobuf_dot_workflows_dot_Workflow__pb2
from deepomatic.rpc.buffers.protobuf.common import Error_pb2 as buffers_dot_protobuf_dot_common_dot_Error__pb2
from deepomatic.rpc.buffers.protobuf.workflows import WorkOrder_pb2 as buffers_dot_protobuf_dot_workflows_dot_WorkOrder__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2buffers/protobuf/workflows/WorkflowExecution.proto\x12\x1a\x62uffers.protobuf.workflows\x1a)buffers/protobuf/workflows/Workflow.proto\x1a#buffers/protobuf/common/Error.proto\x1a*buffers/protobuf/workflows/WorkOrder.proto\"\xb1\x05\n\x0fWorkflowRequest\x12Z\n\x10workflow_entries\x18\x01 \x03(\x0b\x32@.buffers.protobuf.workflows.WorkflowRequest.WorkflowEntriesEntry\x12K\n\x08metadata\x18\x02 \x03(\x0b\x32\x39.buffers.protobuf.workflows.WorkflowRequest.MetadataEntry\x12\x1a\n\x12output_routing_key\x18\x03 \x01(\t\x12\x1d\n\x15return_flow_container\x18\x04 \x01(\x08\x12,\n$return_flow_container_without_images\x18\x05 \x01(\x08\x12:\n\x07wo_data\x18\x06 \x01(\x0b\x32).buffers.protobuf.workflows.WorkOrderData\x12\\\n\x11\x61nalysis_metadata\x18\x07 \x03(\x0b\x32\x41.buffers.protobuf.workflows.WorkflowRequest.AnalysisMetadataEntry\x12\x17\n\x0ftask_group_name\x18\x08 \x01(\t\x12\x12\n\nextra_data\x18\t \x01(\t\x1a[\n\x14WorkflowEntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.buffers.protobuf.workflows.Concept:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15\x41nalysisMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x02\n\x10WorkflowResponse\x12-\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1e.buffers.protobuf.common.Error\x12L\n\x08outcomes\x18\x02 \x03(\x0b\x32:.buffers.protobuf.workflows.WorkflowResponse.OutcomesEntry\x12\x41\n\x0e\x66low_container\x18\x03 \x01(\x0b\x32).buffers.protobuf.workflows.FlowContainer\x1aT\n\rOutcomesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.buffers.protobuf.workflows.Outcome:\x02\x38\x01\x32\xfc\x01\n\x10WorkflowExecutor\x12n\n\x0f\x45xecuteWorkflow\x12+.buffers.protobuf.workflows.WorkflowRequest\x1a,.buffers.protobuf.workflows.WorkflowResponse\"\x00\x12x\n\x15\x45xecuteWorkflowStream\x12+.buffers.protobuf.workflows.WorkflowRequest\x1a,.buffers.protobuf.workflows.WorkflowResponse\"\x00(\x01\x30\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.workflows.WorkflowExecution_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKFLOWREQUEST_WORKFLOWENTRIESENTRY._options = None
  _WORKFLOWREQUEST_WORKFLOWENTRIESENTRY._serialized_options = b'8\001'
  _WORKFLOWREQUEST_METADATAENTRY._options = None
  _WORKFLOWREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _WORKFLOWREQUEST_ANALYSISMETADATAENTRY._options = None
  _WORKFLOWREQUEST_ANALYSISMETADATAENTRY._serialized_options = b'8\001'
  _WORKFLOWRESPONSE_OUTCOMESENTRY._options = None
  _WORKFLOWRESPONSE_OUTCOMESENTRY._serialized_options = b'8\001'
  _WORKFLOWREQUEST._serialized_start=207
  _WORKFLOWREQUEST._serialized_end=896
  _WORKFLOWREQUEST_WORKFLOWENTRIESENTRY._serialized_start=699
  _WORKFLOWREQUEST_WORKFLOWENTRIESENTRY._serialized_end=790
  _WORKFLOWREQUEST_METADATAENTRY._serialized_start=792
  _WORKFLOWREQUEST_METADATAENTRY._serialized_end=839
  _WORKFLOWREQUEST_ANALYSISMETADATAENTRY._serialized_start=841
  _WORKFLOWREQUEST_ANALYSISMETADATAENTRY._serialized_end=896
  _WORKFLOWRESPONSE._serialized_start=899
  _WORKFLOWRESPONSE._serialized_end=1195
  _WORKFLOWRESPONSE_OUTCOMESENTRY._serialized_start=1111
  _WORKFLOWRESPONSE_OUTCOMESENTRY._serialized_end=1195
  _WORKFLOWEXECUTOR._serialized_start=1198
  _WORKFLOWEXECUTOR._serialized_end=1450
# @@protoc_insertion_point(module_scope)
